@@ -1,7 +1,7 @@
 use static_assertions::assert_not_impl_all;
-use std::ffi::CStr;
 use std::os::raw::c_int;
 use std::ptr::NonNull;
+use std::{ffi::CStr, marker::PhantomData};
 
 use crate::bind;
 
@@ -10,15 +10,21 @@ use self::{
     trackball::Trackballs,
 };
 
+use super::game_controller::GameController;
+
 pub mod axis;
 pub mod button;
+pub mod event;
 pub mod guid;
 pub mod hat;
 pub mod power_level;
 pub mod trackball;
 
 #[derive(Debug, Clone, PartialEq)]
-pub struct JoystickId(u32);
+pub struct JoystickId<'joystick> {
+    pub(super) id: u32,
+    pub(super) _phantom: PhantomData<&'joystick Joystick>,
+}
 
 pub struct Joystick {
     ptr: NonNull<bind::SDL_Joystick>,
@@ -27,15 +33,29 @@ pub struct Joystick {
 assert_not_impl_all!(Joystick: Send, Sync);
 
 impl Joystick {
+    pub(super) fn new(device_index: u32) -> Self {
+        let ptr = unsafe { bind::SDL_JoystickOpen(device_index as c_int) };
+        Self {
+            ptr: NonNull::new(ptr).unwrap(),
+        }
+    }
+
+    pub(crate) fn ptr(&self) -> &NonNull<bind::SDL_Joystick> {
+        &self.ptr
+    }
+
     pub fn from_id(id: JoystickId) -> Option<Self> {
-        let ptr = unsafe { bind::SDL_JoystickFromInstanceID(id.0 as bind::SDL_JoystickID) };
+        let ptr = unsafe { bind::SDL_JoystickFromInstanceID(id.id as bind::SDL_JoystickID) };
         NonNull::new(ptr).map(|ptr| Self { ptr })
     }
 
     pub fn instance_id(&self) -> JoystickId {
         let raw = unsafe { bind::SDL_JoystickInstanceID(self.ptr.as_ptr()) };
         debug_assert_ne!(raw, -1);
-        JoystickId(raw as u32)
+        JoystickId {
+            id: raw as u32,
+            _phantom: PhantomData,
+        }
     }
 
     pub fn power_level(&self) -> PowerLevel {
@@ -79,6 +99,16 @@ impl Joystick {
         Hats::new(self)
     }
 }
+
+impl From<GameController> for Joystick {
+    fn from(gc: GameController) -> Self {
+        let ptr = unsafe { bind::SDL_GameControllerGetJoystick(gc.ptr.as_ptr()) };
+        Self {
+            ptr: NonNull::new(ptr).unwrap(),
+        }
+    }
+}
+
 pub struct JoystickSet(Vec<Joystick>);
 
 impl JoystickSet {
@@ -87,14 +117,7 @@ impl JoystickSet {
             bind::SDL_InitSubSystem(bind::SDL_INIT_JOYSTICK);
             bind::SDL_NumJoysticks()
         } as u32;
-        let joysticks = (0..num_joysticks)
-            .map(|index| {
-                let ptr = unsafe { bind::SDL_JoystickOpen(index as c_int) };
-                Joystick {
-                    ptr: NonNull::new(ptr).unwrap(),
-                }
-            })
-            .collect();
+        let joysticks = (0..num_joysticks).map(Joystick::new).collect();
         Self(joysticks)
     }
 }
