@@ -1,6 +1,8 @@
 use std::os::raw::c_int;
 use std::ptr::NonNull;
 
+use static_assertions::assert_not_impl_all;
+
 use crate::color::Rgba;
 use crate::{bind, Result, Sdl, SdlError};
 
@@ -8,6 +10,8 @@ pub struct Palette {
     palette: NonNull<bind::SDL_Palette>,
 }
 
+assert_not_impl_all!(Palette: Send, Sync);
+
 impl Palette {
     pub fn new(num_colors: u32) -> Result<Self> {
         NonNull::new(unsafe { bind::SDL_AllocPalette(num_colors as c_int) }).map_or_else(
