@@ -4,7 +4,7 @@ use crate::bind;
 
 use super::{Point, Size};
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
 pub struct Rect {
     pub up_left: Point,
     pub size: Size,
@@ -56,48 +56,37 @@ impl Rect {
                 raw.as_mut_ptr(),
             )
         };
-        if ret == 0 {
-            None
-        } else {
-            Some(unsafe { raw.assume_init() }.into())
-        }
+        (ret != 0).then(|| unsafe { raw.assume_init() }.into())
     }
 
-    pub fn has_intersection(&self, other: &Self) -> bool {
+    pub fn has_intersection(self, other: Self) -> bool {
         unsafe {
-            bind::SDL_HasIntersection(
-                &self.clone().into() as *const _,
-                &other.clone().into() as *const _,
-            ) != 0
+            bind::SDL_HasIntersection(&self.into() as *const _, &other.into() as *const _) != 0
         }
     }
 
-    pub fn intersect(&self, other: &Self) -> Option<Self> {
+    pub fn intersect(self, other: Self) -> Option<Self> {
         let mut raw = MaybeUninit::uninit();
         let ret = unsafe {
             bind::SDL_IntersectRect(
-                &self.clone().into() as *const _,
-                &other.clone().into() as *const _,
+                &self.into() as *const _,
+                &other.into() as *const _,
                 raw.as_mut_ptr(),
             )
         };
-        if ret == 0 {
-            None
-        } else {
-            Some(unsafe { raw.assume_init() }.into())
-        }
+        (ret != 0).then(|| unsafe { raw.assume_init() }.into())
     }
 
     pub fn empty(&self) -> bool {
         self.size.width != 0 || self.size.height != 0
     }
 
-    pub fn union(&self, other: &Self) -> Self {
+    pub fn union(self, other: Self) -> Self {
         let mut raw = MaybeUninit::uninit();
         unsafe {
             bind::SDL_UnionRect(
-                &self.clone().into() as *const _,
-                &other.clone().into() as *const _,
+                &self.into() as *const _,
+                &other.into() as *const _,
                 raw.as_mut_ptr(),
             )
         }
