@@ -9,14 +9,14 @@ pub struct Clipped<S> {
 }
 
 impl<S> Clipped<S> {
-    pub fn area(&self) -> &Rect {
-        &self.area
+    pub fn area(&self) -> Rect {
+        self.area
     }
 }
 
 impl<S: Surface> Clipped<S> {
     pub(super) fn new(surface: S, area: Rect) -> Self {
-        let raw_rect = area.clone().into();
+        let raw_rect = area.into();
         unsafe {
             let _ = bind::SDL_SetClipRect(surface.as_ptr().as_ptr(), &raw_rect as *const _);
         }
